==> MT-1.1.tar.gz: MT-1.1/lib/MT/Permission.pm <==
# Copyright 2001 Benjamin Trott. This code cannot be redistributed without
# permission from www.movabletype.org.
#
# $Id: Permission.pm,v 1.10 2001/10/08 11:25:13 btrott Exp $

package MT::Permission;
use strict;

use base qw( MT::Object );
__PACKAGE__->install_properties({
    columns => [
        'id', 'author_id', 'blog_id', 'role_mask',
    ],
    indexes => {
        blog_id => 1,
        author_id => 1,
    },
    datasource => 'permission',
    primary_key => 'id',
});

{
    my @Perms = (
#        [ 1, 'login', 'Can login?', ],
        [ 2, 'post', 'Can post to this blog?', ],
        [ 4, 'upload', 'Can upload?', ],
        [ 8, 'edit_all_posts', 'Can edit all posts?', ],
        [ 16, 'edit_templates', 'Can edit templates?', ],
        [ 32, 'edit_authors', 'Can edit authors?', ],
        [ 64, 'edit_config', 'Can edit blog configuration?', ],
        [ 128, 'rebuild', 'Can rebuild files?', ],
        [ 256, 'send_notifications', 'Can send notifications?', ],
        [ 512, 'edit_categories', 'Can edit categories?', ],
        [ 1024, 'edit_notifications', 'Can edit notification list?' ],
    );

    sub set_full_permissions {
        my $perms = shift;
        my $mask = 0;
        for my $ref (@Perms) {
            $mask += $ref->[0];
        }
        $perms->role_mask($mask);
    }

    sub perms { \@Perms }

    no strict 'refs';
    for my $ref (@Perms) {
        my $mask = $ref->[0];
        my $meth = 'can_' . $ref->[1];
        *$meth = sub {
            my $flags = $_[0]->role_mask || 0;
            if (@_ == 2) {
                $flags = $_[1] ? ($flags | $mask) :
                                 ($flags & ~$mask);
                $_[0]->role_mask($flags);
            }
            $flags & $mask;
        };
    }
}

1;

==> MT-1.4.tar.gz: MT-1.4/lib/MT/Permission.pm <==
# Copyright 2001, 2002 Benjamin Trott. This code cannot be redistributed without
# permission from www.movabletype.org.
#
# $Id: Permission.pm,v 1.12 2002/01/05 22:46:07 btrott Exp $

package MT::Permission;
use strict;

use MT::Object;
@MT::Permission::ISA = qw( MT::Object );
__PACKAGE__->install_properties({
    columns => [
        'id', 'author_id', 'blog_id', 'role_mask',
    ],
    indexes => {
        blog_id => 1,
        author_id => 1,
    },
    datasource => 'permission',
    primary_key => 'id',
});

{
    my @Perms = (
#        [ 1, 'login', 'Can login?', ],
        [ 2, 'post', 'Can post to this blog?', ],
        [ 4, 'upload', 'Can upload?', ],
        [ 8, 'edit_all_posts', 'Can edit all posts?', ],
        [ 16, 'edit_templates', 'Can edit templates?', ],
        [ 32, 'edit_authors', 'Can edit authors?', ],
        [ 64, 'edit_config', 'Can edit blog configuration?', ],
        [ 128, 'rebuild', 'Can rebuild files?', ],
        [ 256, 'send_notifications', 'Can send notifications?', ],
        [ 512, 'edit_categories', 'Can edit categories?', ],
        [ 1024, 'edit_notifications', 'Can edit notification list?' ],
    );

    sub set_full_permissions {
        my $perms = shift;
        my $mask = 0;
        for my $ref (@Perms) {
            $mask += $ref->[0];
        }
        $perms->role_mask($mask);
    }

    sub perms { \@Perms }

    no strict 'refs';
    for my $ref (@Perms) {
        my $mask = $ref->[0];
        my $meth = 'can_' . $ref->[1];
        *$meth = sub {
            my $flags = $_[0]->role_mask || 0;
            if (@_ == 2) {
                $flags = $_[1] ? ($flags | $mask) :
                                 ($flags & ~$mask);
                $_[0]->role_mask($flags);
            }
            $flags & $mask;
        };
    }
}

1;
